# -*- coding: utf-8 -*-
"""
file: spd_prefs.py

Desrciption:  
    loads preferences 

"""

import os

def get_spedas_prefs():
    """Get all the spedas preferences and return a directory"""    
    
    import pyspedas
    dir_path = os.path.abspath(os.path.dirname(pyspedas.__file__))
    fname = os.path.join(dir_path, 'spd_prefs_txt.py')
    print("Preferences file: " + fname )
    
    """Read preferences"""
    with open(fname) as f:
        content = f.readlines()
    content = [x.strip() for x in content] 
    
    """Fill dictionary""" 
    ans_dict = {}
    for line in content:
        if len(line)>2 or line[0]!="#":
            terms = line.split('=')
            terms = [x.strip() for x in terms]
            if len(terms)==2:
                if terms[0]!='' and terms[1]!='':
                    ans_dict[terms[0].replace("'","")] = terms[1].replace("'","")
                
    return ans_dict
            
    


from core import load_data, spd_version
from spd_prefs import get_spedas_prefs
from spd_helpers import download_files, url_exists, find_latest_url_version, get_probes, get_instruments
from spd_dates import validate_date, get_date_list, get_dates
from spd_themis import themis_filename, load_themis



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages


with open('README.md') as f:
    readme = f.read()

with open('LICENSE.txt') as f:
    license = f.read()

setup(
    name='pyspedas',
    version='0.2.2',
    description='Package for SPEDAS data loading modules',
    long_description=readme,
    long_description_content_type='text/markdown',
    url='https://github.com/nickssl/pyspedas',
    author='Nick Hatzigeorgiu',
    author_email='nikos@berkeley.edu',
    license='MIT',
    classifiers=['Development Status :: 3 - Alpha', 
                 'Intended Audience :: Developers',
                 'Topic :: Scientific/Engineering',
                 'License :: OSI Approved :: MIT License',
                 'Programming Language :: Python :: 3',
    ],
    keywords='spedas data tools',
    project_urls={'Information': 'http://spedas.org/wiki/',
                 },    
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),          
    install_requires=['pytplot'],
    python_requires='>=3',
)

